@@ -1,5 +1,10 @@
 from audmath.core.api import (
+    db,
+    inverse_db,
     inverse_normal_distribution,
+    rms,
+    duration_in_seconds,
+    window,
 )
 
 # Discourage from audmath import *
